@@ -1,4 +1,4 @@
-# Copyright (C) 2003-2006 by the gtk2-perl team (see the file AUTHORS for
+# Copyright (C) 2003-2005 by the gtk2-perl team (see the file AUTHORS for
 # the full list)
 # 
 # This library is free software; you can redistribute it and/or modify it under
@@ -15,7 +15,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Glib.pm,v 1.85.2.7 2006/02/12 16:57:54 kaffeetisch Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Glib.pm,v 1.88 2005/10/18 16:39:44 kaffeetisch Exp $
 #
 
 package Glib;
@@ -61,7 +61,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = map { @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 
-our $VERSION = '1.105';
+our $VERSION = '1.110';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
@@ -172,43 +172,6 @@ sub tie_properties
 	}
 }
 
-package Glib::Object::_LazyLoader;
-
-use strict;
-no strict qw(refs);
-use vars qw($AUTOLOAD);
-push @Carp::CARP_NOT, __PACKAGE__;
-
-# These two overrides won't keep explicit calls to UNIVERSAL::(isa|can)
-# from breaking if called before anything is loaded, but those should
-# be quite rare.
-
-sub isa {
-	# we really shouldn't get in here at all if $_[0] is undefined.
-	_load (ref($_[0]) || $_[0]);
-	$_[0]->SUPER::isa ($_[1]);
-}
-
-sub can {
-	# we really shouldn't get in here at all if $_[0] is undefined.
-	_load (ref($_[0]) || $_[0]);
-	$_[0]->SUPER::can ($_[1]);
-}
-
-sub AUTOLOAD {
-	(my $method = $AUTOLOAD) =~ s/^.*:://;
-	(my $lazy_class = $AUTOLOAD) =~ s/::[^:]*$//;
-	my $object_or_type = shift;
-
-	_load ($lazy_class);
-
-	die "Something is very broken, couldn't lazy load $lazy_class"
-		if $object_or_type->isa (__PACKAGE__);
-
-	# try again
-	return $object_or_type->$method (@_);
-}
-
 package Glib;
 
 1;
@@ -466,6 +429,46 @@ these messages through Perl's native system, warn() and die().  Extensions
 should register the log domains they wrap for this to happen fluidly.
 [FIXME say more here]
 
+=head1 64 BIT INTEGERS
+
+Since perl's integer data type can only hold 32 bit values on all 32 bit
+machines and even on some 64 bit machines, Glib converts 64 bit integers to and
+from strings if necessary.  These strings can then be used to feed one of the
+various big integer modules.  Make sure you don't let your strings get into
+numerical context before passing them into a Glib function because in this
+case, perl will convert the number to scientific notation which at this point
+is not understood by Glib's converters.
+
+Here is an overview of what big integer modules are available.  First of all,
+there's Math::BigInt.  It has everything you will ever need, but its pure-Perl
+implementation is also rather slow.  There are multiple ways around this,
+though.
+
+=over
+
+=item L<Math::BigInt::FastCalc>
+
+L<Math::BigInt::FastCalc> can help avoid the glacial speed of vanilla
+L<Math::BigInt::Calc>.  Recent versions of L<Math::BigInt> will automatically
+use L<Math::BigInt::FastCalc> in place of L<Math::BigInt::Calc> when available.
+Other options include L<Math::BigInt::GMP> or L<Math::BigInt::Pari>, which
+however have much larger dependencies.
+
+=item L<Math::BigInt::Lite>
+
+Then there's L<Math::BigInt::Lite>, which uses native Perl integer operations
+as long as Perl integers have sufficient range, and upgrades itself to
+L<Math::BigInt> when Perl integers would overflow. This must be used in place
+of L<Math::BigInt>.
+
+=item L<bigint> / L<bignum> / L<bigfloat>
+
+Finally, there's the bigint/bignum/bigfloat pragmata, which automatically load
+the corresponding Math:: modules and which will autobox constants.
+bignum/bigint will automatically use L<Math::BigInt::Lite> if it's available.
+
+=back
+
 =head1 Exports
 
 For the most part, gtk2-perl avoids exporting things.  Nothing is exported by
@@ -521,7 +524,7 @@ GLib-based C libraries to perl.
 
   Yet another document, available separately, ties it all together:
     http://gtk2-perl.sourceforge.net/doc/binding_howto.pod.html
-
+  
 For gtk2-perl itself, see its website at
 
   gtk2-perl - http://gtk2-perl.sourceforge.net/
@@ -545,7 +548,7 @@ patches and tests here and there.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2006 by muppet and the gtk2-perl team
+Copyright 2003-2005 by muppet and the gtk2-perl team
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the Lesser General Public License (LGPL).  For 
